@@ -16,7 +16,7 @@ use Module::Metadata;
 use Scalar::Util ();
 use Test::More 0.88;
 
-our $VERSION = '0.000_912';
+our $VERSION = '0.000_915';
 
 our @EXPORT_OK = qw{ all_prereq_ok file_prereq_ok prereq_ok };
 our %EXPORT_TAGS = (
@@ -55,6 +55,7 @@ sub new {
 	meta_file	=> [ qw{
 	    MYMETA.json MYMETA.yml META.json META.yml } ],
 	prune	=> [],
+	uses	=> [],
     };
     foreach my $name ( keys %{ $default } ) {
 	$arg{$name} //= $default->{$name};
@@ -83,7 +84,7 @@ sub new {
     foreach my $phase ( qw{ configure build test runtime } ) {
 	my $reqs = $prereqs->requirements_for( $phase, 'requires' );
 	foreach my $module ( $reqs->required_modules() ) {
-	    $requires{$module} = 1;
+	    $requires{$module} = {};
 	}
     }
 
@@ -99,22 +100,41 @@ sub new {
 	;
     delete $has{perl};
 
-    return bless {
+    if ( my @dup = grep { $requires{$_} } @{ $arg{accept} } ) {
+	diag "The following @{[
+	    @dup == 1 ? 'module appears' : 'modules appear'
+	    ]} in both the prerequisites and\nthe 'accept' argument: ",
+	    join ', ', @dup;
+    }
+
+    delete $arg{accept};
+    delete $arg{_meta_file};
+    delete $arg{path_type};
+
+    my $self = bless {
 	# accept		=> $arg{accept},
 	# core_modules	=> $core_modules,
-	file_error	=> $arg{file_error},
+	file_error	=> delete $arg{file_error},
 	has		=> \%has,
-	meta_file	=> $arg{meta_file},
+	meta_file	=> delete $arg{meta_file},
 	meta_data	=> $meta_data,
-	name		=> $arg{name},
-	per_file_note	=> $arg{per_file_note},
-	perl_version	=> $arg{perl_version},
-	prune		=> $arg{prune},
+	name		=> delete $arg{name},
+	per_file_note	=> delete $arg{per_file_note},
+	perl_version	=> delete $arg{perl_version},
+	prune		=> delete $arg{prune},
 	# provides	=> $provides,
-	# requires	=> \%requires,
-	skip_name	=> $arg{skip_name},
-	_normalize_path	=> $arg{_normalize_path},
+	skip_name	=> delete $arg{skip_name},
+	uses		=> { map { $_ => 1 } perl => @{ delete $arg{uses} } },
+	_normalize_path	=> delete $arg{_normalize_path},
+	_requires	=> \%requires,
     }, ref $class || $class;
+
+    if ( my $num = keys %arg ) {
+	croak "Unknown argument@{[ $num > 1 ? 's' : '' ]} ", join ', ',
+	    map { "'$_'" } sort keys %arg;
+    }	
+
+    return $self;
 }
 
 sub all_prereq_ok {
@@ -158,6 +178,22 @@ sub all_prereq_ok {
     return $ok;
 }
 
+sub all_prereqs_used {
+    my ( $self ) = @_;
+
+    state $TEST = Test::More->builder();
+    local $Test::Builder::Level = _nest_depth();
+
+    my @unused = sort
+	grep { ! $self->{uses}{$_} && ! $self->{_requires}{$_}{file} }
+	keys %{ $self->{_requires} };
+    my $rslt = $TEST->ok( ! @unused, 'All required modules are used' )
+	or $TEST->diag( "The following @{[
+	    @unused == 1 ? 'prerequisite is' : 'prerequisites are'
+	    ]} unused: ", join ', ', @unused );
+    return $rslt;
+}
+
 sub file_prereq_ok {
     my ( $self, $file, @arg ) = _unpack_args( @_ );
     @arg
@@ -228,6 +264,9 @@ sub file_prereq_ok {
 	$module_found{$module}++
 	    and next;
 
+	$self->{_requires}{$module}
+	    and push @{ $self->{_requires}{$module}{file} ||= [] }, $file;
+
 	$need_skip = 0;
 	$TEST->ok(
 	    $self->{has}{$module} || 0,
@@ -324,7 +363,7 @@ sub __normalize_path_VMS {
 sub __normalize_path_Win32 { s| \\ |/|smxg; }	## no critic (RequireFinalReturn)
 
 # We don't use Module::Metadata->provides(), because it filters out
-# private methods. While we're at it, we just process every .pm we find.
+# private packages. While we're at it, we just process every .pm we find.
 sub _provides {
     my %provides;
     my $manifest = ExtUtils::Manifest::maniread();
@@ -460,8 +499,12 @@ This class supports the following public methods:
  my $tpm = Test::Prereq::Meta->new();
 
 This static method instantiates the test object and reads in the meta
-data that contain the prerequisites. It accepts the following arguments
-as name/value pairs:
+data that contain the prerequisites.
+
+B<Caveat:> the resultant object should not be used to test more than one
+distribution.
+
+This method accepts the following arguments as name/value pairs:
 
 =over
 
@@ -469,7 +512,9 @@ as name/value pairs:
 
 This argument is the name of a module, or a reference to an array of
 module names. These modules will be passed even if they are not listed
-as prerequisites.
+as prerequisites. However, if any module listed here is found in the
+prerequisites, a diagnostic will be generated when the object is
+instantiated.
 
 The default is C<[]>, that is, a reference to an empty array.
 
@@ -581,8 +626,18 @@ and C<'%e'> substitutions are not relevant to this template.
 
 The default value is C<'Prereq test: %f does not use any modules'>.
 
+=item uses
+
+This argument is the name of a module, or a reference to an array of
+module names. The L<all_prereqs_used()|/all_prereqs_used> test will
+count these as having been used, even if no use of them is found.
+
+The default is C<[]>, that is, a reference to an empty array.
+
 =back
 
+The use of arguments other than the above will result in an exception.
+
 Arguments C<'file_error'>, C<'name'>, C<'per_file_note'>, and
 C<'skip_name'> are templates for generating the actual text to be
 emitted. Selected data can be substituted into the template.
@@ -631,6 +686,18 @@ This method can also be exported and called as a subroutine, in which
 case it functions as though its invocant were the default object, i.e.
 one instantiated with no arguments.
 
+=head2 all_prereqs_used
+
+ $tpm->all_prereqs_used()
+
+This method tests whether all prerequisites have been used. If it fails,
+it emits a diagnostic saying which prerequisites are unused.
+
+This method will not work as desired unless the invocant was also used
+to test all relevant files in the distribution using
+L<all_prereq_ok()|/all_prereq_ok> or
+L<file_prereq_ok()|/file_prereq_ok>.
+
 =head2 file_prereq_ok
 
  $tpm->file_prereq_ok( $file_name );
